<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Infetech_Elementor_Service_Toggle extends Widget_Base {

	public function get_name() {
		return 'infetech_elementor_service_toggle';
	}

	public function get_title() {
		return esc_html__( 'Service Toggle', 'infetech' );
	}

	public function get_icon() {
		return 'eicon-toggle';
	}

	public function get_categories() {
		return [ 'infetech' ];
	}

	public function get_script_depends() {
		return [ 'infetech-elementor-service-toggle' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'infetech' ),
			]
		);	
			
			// Add Class control
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'class_icon',
				[
					'label' => esc_html__( 'Icon', 'infetech' ),
					'type' => Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon-infetech-connection',
						'library' 	=> 'flaticon',
					],
				]
			);

			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'infetech' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'AI & Machine Learning', 'infetech' ),
					'label_block' => true,
				]
			);

			$repeater->add_control(
				'description',
				[
					'label' => esc_html__( 'Description', 'infetech' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'Want more efficiency in your organization? Asana is easy for all teams', 'infetech' ),
					'label_block' => true,
				]
			);

			$repeater->add_control(
				'content',
				[
					'label' => esc_html__( 'Content', 'infetech' ),
					'type' => Controls_Manager::WYSIWYG,
					'default' => esc_html__( 'Service Content', 'infetech' ),
				]
			);

			$this->add_control(
				'tab_items',
				[
					'label' => esc_html__( 'Items', 'infetech' ),
					'type' => Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'title' => esc_html__( 'AI & Machine Learning', 'infetech' ),
							'class_icon' => [
								'value'    => 'flaticon-infetech-connection',
								'library'  => 'flaticon'
							] 
						],
						[
							'title' => esc_html__( 'Blockchain development', 'infetech' ),
							'class_icon' => [
								'value'    => 'flaticon-infetech-blockchain',
								'library'  => 'flaticon'
							] 
						],
						[
							'title' => esc_html__( 'Data analytic Structuring', 'infetech' ),
							'class_icon' => [
								'value'    => 'flaticon-infetech-data-analytics-1',
								'library'  => 'flaticon'
							] 
						],
						[
							'title' => esc_html__( 'Cloud Computing', 'infetech' ),

							'class_icon' => [
								'value'    => 'flaticon-infetech-servers-1',
								'library'  => 'flaticon'
							] 
						],
					],
					'title_field' => '{{{ title }}}',
				]
			);

		$this->end_controls_section();

		/* Begin icon Style */
		$this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon', 'infetech' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );                 

			$this->add_responsive_control(
				'size_icon',
				[
					'label' 		=> esc_html__( 'Size', 'infetech' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-service-toggle .item .toggle .icon i ' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'infetech' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-toggle .item .toggle .icon i ' => 'color: {{VALUE}};',
					],
				]
			);


        $this->end_controls_section();

		/* Begin Title Style */
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'infetech' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-service-toggle .item .toggle .title',
				]
			);
				
			$this->add_control(
				'title_color_link_normal',
				[
					'label' 	=> esc_html__( 'Color', 'infetech' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-toggle .item .toggle .title' => 'color: {{VALUE}}',
					],
				]
			);

			$this->end_controls_tab();

			$this->add_responsive_control(
				'title_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'infetech' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-service-toggle .item .toggle .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		/* End Title Style */
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$items    = $settings['tab_items'];

		?>

		  	<div class="ova-service-toggle">
            	
		        <?php foreach( $items as $k => $item ) { 
	               $class_icon  = $item['class_icon'];
	           	   $title       = $item['title'];
	           	   $description = $item['description'];
	           	   $content     = $item['content'];
			    ?>

				<div class="item">

					<div class="toggle">
						<div class="heading-wrap">
							<?php if ( !empty ($class_icon['value'])) : ?>
								<div class="icon">
									<?php 
									    \Elementor\Icons_Manager::render_icon( $class_icon, [ 'aria-hidden' => 'true' ] );
									?> 
								</div>
							<?php endif; ?>
							<?php if ( !empty ($title)) : ?>
								<h3 class="title">
									<?php echo esc_html($title) ; ?>
								</h3>
							<?php endif; ?>
						</div>

						<div class="info-wrap">
							<?php if ( !empty ($description)) : ?>
								<p class="description">
									<?php echo esc_html($description) ; ?>
								</p>
							<?php endif; ?>
							<div class="toggle-icon <?php if($k == 1) printf('active'); ?>">
								<?php if($k == 1) { ?>
									<i aria-hidden="true" class="flaticoninfetech- flaticon-infetech-minus-sign"></i>
								<?php } else { ?>
									<i aria-hidden="true" class="flaticoninfetech- flaticon-infetech-plus"></i>
								<?php } ?>
							</div>
						</div>
					</div>

					<div class="service-content <?php if($k == 1) printf('active'); ?>">
						<div class="spacing"></div>
						<div class="content">
							<?php printf($content); ?> 
						</div>
					</div>
				</div>

				<?php } ?>

			</div>

		<?php
	}

	
}
$widgets_manager->register( new Infetech_Elementor_Service_Toggle() );